<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: MXCreateForm.php 4606 2006-07-12 22:41:37Z morgabra $

/**
 *  MXCreateForm.php - contains the {@link MXCreateForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is used for creating MX Records
 *  
 *  @package    htdocs
 *  @subpackage forms
 */
class MXCreateForm extends MaintainForm
{

//{{{   vars
   
    /**
     *  Dirty cheat to map form elements to dbdo vars
     */
    var $map = array("Name"=>"name",
                    "Domain"=>"domain",
                    "Server_Name"=>"server",
                    "Priority"=>"priority",
                    "Status"=>"enabled",
                    "TTL"=>"ttl");
    
//}}}

//{{{   form_init_elements()

    /**
     *  This method initializes all of the elements of the form
     */
    function form_init_elements()
    {
        $name       = new FEText(_("Name"), false);
        $domchk     = new FECheckbox(_("Entire Domain"));
        $domains    = new FEListBox(_("Domain"), true);
        $server     = new FEText(_("Server Name"), true);
        $priority   = new FEListBox(_("Priority"), true);
        $ttl        = new FEText(_("TTL"), true);
   
        $domains->set_list_data($this->_domains());
        $priority->set_list_data(array("5"=>5,
                                        "10"=>10,
                                        "15"=>15));

        $this->add_elements($name, $domchk, $domains, $server, $priority, $ttl);
        $this->set_action($_SERVER["SCRIPT_NAME"]);
        
    }
//}}}
//{{{   form_init_data()
    /*  Initialize the form elements. In create forms this is the global $conf
     *  defaults.
     *
     */
    function form_init_data()
    {
        global $conf;
        $this->set_element_value(_("TTL"), $conf['soa']['default_mx_ttl']); 
    }
    
//}}}
//{{{   form_backend_validation()

    /**
     *  This method validates the values that were given before processing.
     *
     *  @return Boolean     True if data is valid
     */
    function form_backend_validation()
    {
        $vals = $this->get_all_element_values();
        $res = true;

        if( !($vals[_("Name")] || $vals[_("Entire_Domain")] == 1) ) {
            $res = false;
            $this->add_error(_("Name"),
                        _("Must either use a name or specify the entire domain"));
            $this->add_error(_("Entire Domain"), 
                        _("Must either use name or specify the entire domain"));

        } else {
            
            $dbdobj = new MX($_REQUEST['id']);
            $dbdobj->setAll();
            $dbdobj->setFrom($this->remap($vals, DBDO));
            $dbdobj->zone = $_SESSION['zone'];
            
            //If we're using a subdomain instead of makeing a name in a domain
            if($vals[_('Entire_Domain')]) {
                $dom = new Domain($vals[_("Domain")]);
                
                //Make sure it is indeed a subdomain
                if(!$dom->master_domain) {
                    $res = false;
                    $this->add_error(_("Domain"),
                        _("Domain's master domain is not in Maintain."));
                }
                //the domain is the master
                $dbdobj->setDomain($dom->master_domain);
                //the name is the subdomain
                $dbdobj->setName(strtok($dom->name,'.'));
                
            }
            
            $valid = $dbdobj->validate();
            
            if($valid !== true) {
                $errors = $this->remap($valid, FORM);
                foreach($errors as $label=>$error) {
                    if($error !== true)
                        $this->add_error($label, $error);
                }
                $res = false;
            }
        }

        return $res;
        
    }

//}}}
//{{{   form_action()

    /**
     *  This method is what processes the data after validation.  In this case
     *  it creates a MX record.
     *
     *  @return Boolean     True if action was successful
     */
    function form_action()
    {
        global $user;
    
        $res = true;
        switch(strtolower($this->get_action())) {
        
        case _("submit"):
            
            $vals = $this->get_all_element_values();
        
            $dbdobj = new MX();
            $dbdobj->query("BEGIN");
            $dbdobj->setAll();
            $dbdobj->setFrom($this->remap($vals, DBDO));
            $dbdobj->zone = $_SESSION['zone'];

            if($vals[_('Entire_Domain')]) {
                $dom = new Domain($vals[_("Domain")]);
                $dbdobj->setDomain($dom->master_domain);
                $dbdobj->setName(strtok($dom->name,'.'));
            }

            if(!$dbdobj->insert()) {
                $dbdobj->query("ROLLBACK");
                $res = false;
                $this->add_action(_("ERROR"), 
                        _("Failed to insert MX Record into the database."));
            } else {
                $dbdobj->query("COMMIT");
                $dbdobj->write_history(_("MX Record created"), ACTION_CREATE,
                                        $user->username, $_SESSION['zone']);
            }
            break;

        default:
            die_hard(_("Invalid form action"));
            break;
        
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method lets them know they were successful in creating the record
     *  and allows them to go back to the index or to the list.
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a("index.php", "[Return to Home]");
        $link = html_a("mx.php", "[Return to MX List]");
        $div->add(container("MX Record created successfully!",html_br()));
        $div->add(container($indlink, $link));
        return $div; 
    }

//}}}

/*Helper Methods*/
//{{{   _domains()

    /**
     *  Helper method.  Gets the domains the user has access too and uses that
     *  to populate the listbox of domains.
     *
     *  @return Array   Array of domains keyed by name
     */
    function _domains()
    {
        global $user;

        $domarray = array();
        
        $zd = DB_DataObject::Factory('zone_domain');
        if(!$user->is_admin())
            $zd->zone = $_SESSION['zone'];
        $dom = DB_DataObject::Factory('domain');
        $dom->joinAdd($zd);
        $dom->orderBy("name ASC");
        $dom->find();
        while($dom->fetch()) {
            $domarray[$dom->name] = $dom->domain;
        }

        return $domarray;
    }

//}}}

}

?>
