<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: ZoneEditForm.php 4606 2006-07-12 22:41:37Z morgabra $

/**
 *  ZoneEditForm.php - This file contains the {@link ZoneEditForm} class
 *
 *  @author $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

 require_once(FORMDIR."/MaintainForm.php");

/**
 *  ZoneEditForm - this class is the zone edit form, note, this form is responisble
 *                  for stuff in the zone table, not for zone-> domain mappings and 
 *                  such. (That's a different form)
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class ZoneEditForm extends MaintainForm
{

//{{{ Vars

/**
 *  Local hack to map form labels to database fields
 */
/* NOTE: ZB: phphtmllib changes the - in E-Mail to a _ making it look like a " "
space on the way back */
var $map = array("Name"=>"name",
                "Support_Email"=>"support_mail",
                "Notify_Admins_of_Changes"=>"notify",
                "Allow_Hosts_To_Bypass_DHCP"=>"allow_blank_ha",
                "Comment"=>"comment",
                "Purgeable"=>"purgeable");

//}}}

//{{{   form_init_elements()

    /**
     *  This method initializes the fields of the form.
     */
    function form_init_elements()
    {
        $name = new FEText(_("Name"), true);
        $support = new FEEmail(_("Support Email"));
        $support->set_allow_name(false); //disallow "Foo Bar <foo@bar.com>"
        $notify = new FEListBox(_("Notify Admins of Changes"));
        $notify->set_list_data(array("Yes"=>"enabled","No"=>"disabled"));
        $dhcpbypass = new FEListBox(_("Allow Hosts To Bypass DHCP"));
        $dhcpbypass->set_list_data(array("Yes"=>1,"No"=>0));
        $comment = new FETextArea(_("Comment"),true, 5, 40);
        $purgable = new FEListBox(_("Purgeable"));
        $purgable->set_list_data(array("Yes"=>1, "No"=>0));

        $this->add_elements($name, $support, $notify, $dhcpbypass, $comment,
                            $purgable);
    }

//}}}
//{{{   form_init_data()

    /**
     *  This method sets the form values to those that are currently in the 
     *  database
     */
    function form_init_data()
    {
        $zne = new Zone($_REQUEST['id']);
        $array = $zne->toArray(); //get it's values
        
        //Put them in an array that is suitable for forms
        $array = $this->remap($array, FORM);

        //iterate through and set the values
        foreach($array as $label=>$val)
            $this->set_element_value($label, $val);
    }

//}}}
//{{{ form_backend_validation()

    /**
     *  This function makes sure that the form values are valid.
     *
     *  @return Boolean True if form data is valid
     */
    function form_backend_validation()
    {
        $loczone = new Zone($_REQUEST['id']);

        $res = true;
        $elements = $this->get_all_element_values();


        $loczone->setFrom($this->remap($elements, DBDO));

        $valid = $loczone->validate();

        if($valid !== true) {
            $res = false;
            foreach($valid as $label=>$error)
                $this->add_error($label, $error);
        }

        return $res;
    }

//}}}
//{{{   form_action()

    /**
     *  This method is what actually updates the database with the form values.
     *  This method will only be called if validation was successful.
     *
     *  @return Boolean True if action was successful
     */
    function form_action()
    {
        global $user;

        $res = true;
        $array = $this->get_all_element_values();
        $loczone = new Zone($_REQUEST['id']);
        $loczone->query("BEGIN");
        $vals = $this->remap($array,DBDO);
        $loczone->setFrom($vals);

        if($loczone->update() === false) {
            $loczone->query("ROLLBACK");
            $res = false;
            $this->add_error(_("ERROR"),_("Could not update database"));
        } else {
            $loczone->query("COMMIT");
            $loczone->write_history($loczone->comment, ACTION_MODIFY, 
                                    $user->username, $_SESSION['zone']);
        }

        return $res;
    }

//}}}
//{{{ form_success()

    /**
     *  This method returns a div that contains the success method and a road 
     *  back to the standard pages.  It simply informs them of success.
     *
     *  @return DIVTag  $div    Div containing the success message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php",_("[Return to Index]"));
        $zonlink = html_a(web_root()."zone.php",_("[Return to Zone List]"));
        $div->add(_("Zone successfully updated!"), html_br());
        $div->add($indlink, $zonlink);

        return $div;
    }

//}}}
//{{{   form_hidden()

    /**
     *  Add some hidden values that we'll need later.  The ID of the Zone and the
     *  get action so we can get back to the form.
     *
     *  @return Container   Container that has the hidden elements in it
     */
    function form_hidden()
    {
        $action =  new FEHidden(_("action"), $_REQUEST['action']);
        $id = new FEHidden(_("id"), $_REQUEST['id']);

        $this->add_elements($action, $id);

        return container($this->element_form(_('action')), $this->element_form(_('id')));
    }

//}}}


}
