<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2006 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id$

/**
  * IPTest.php - contains the {@link IPTest} test for the {@link IP} class
  *
  * @author$
  * @filesource
  *
  * @package    tests
  * @subpackage classes
  */

require_once 'PHPUnit/TestCase.php';
require_once 'Net/IPv4.php';
require_once CLASSDIR.'/ip.php';

class IPTest extends PHPUnit_TestCase
{
    var $_test_ip = "128.193.0.36";     // valid test IP
    var $_test_int = "2160132132";    // the same IP in int format

    /**
      * empty IPs are invalid. Expect null object.
      */
    function testEmptyIP()
    {
        // constructor errors untestable in PHP4!
        /*
        $ip = new IP("");
        $this->assertNull($ip);
        */
    }
    
    /**
      * bad, bad invalid IP
      */
    function testWrongIP()
    {
        // constructor errors untestable in PHP4!
        /*
        $ip = new IP("I am not an IP");
        $this->assertNull($ip);
        */
    }

    /**
      * valid IP. Should be stored in the public variable $ip_addr
      */
    function testValidIP()
    {
        $ip = new IP($this->_test_int);
        $this->assertEquals($ip->ip_addr, $this->_test_ip);
        $this->assertEquals($ip->ip_int, $this->_test_int);
    }

    // {{{ getSubnet()
    // }}}

    /**
      * Convert an integer representation of an IP to dotted quad
      */
	function testInt2ip() 
    {
        $this->assertEquals(IP::int2ip($this->_test_int), $this->_test_ip);
	} // int2ip

	/** 
      * Check to make sure it's in dotted-quad format 
      */
    function testIsDottedQuad()
    {
        // real IP
        $this->assertTrue(IP::is_dotted_quad($this->_test_ip));

        // wrong IP
        $this->assertFalse(IP::is_dotted_quad("321.515.1000.1"));
    }
    
    // {{{ is_free()
    // }}}
    
    // {{{ ip_exists()
    // }}}
}

?>
